Struct polkadot_cli::RunCmd

source ·
pub struct RunCmd {
Show 13 fields pub base: RunCmd, pub force_kusama: bool, pub force_westend: bool, pub force_rococo: bool, pub no_beefy: bool, pub insecure_validator: bool, pub force_authoring_backoff: bool, pub jaeger_agent: Option<String>, pub pyroscope_server: Option<String>, pub no_hardware_benchmarks: bool, pub overseer_channel_capacity_override: Option<usize>, pub workers_path: Option<PathBuf>, pub disable_worker_version_check: bool,
}

Fields

base: RunCmdforce_kusama: bool

Force using Kusama native runtime.

force_westend: bool

Force using Westend native runtime.

force_rococo: bool

Force using Rococo native runtime.

no_beefy: bool

Disable the BEEFY gadget.

Currently enabled by default on ‘Rococo’, ‘Wococo’ and ‘Versi’.

insecure_validator: bool

Allows a validator to run insecurely outside of Secure Validator Mode. Security features are still enabled on a best-effort basis, but missing features are no longer required. For more information see https://github.com/w3f/polkadot-wiki/issues/4881.

force_authoring_backoff: bool

Enable the block authoring backoff that is triggered when finality is lagging.

jaeger_agent: Option<String>

Add the destination address to the ‘Jaeger’ agent.

Must be valid socket address, of format IP:Port (commonly 127.0.0.1:6831).

pyroscope_server: Option<String>

Add the destination address to the pyroscope agent.

Must be valid socket address, of format IP:Port (commonly 127.0.0.1:4040).

no_hardware_benchmarks: bool

Disable automatic hardware benchmarks.

By default these benchmarks are automatically ran at startup and measure the CPU speed, the memory bandwidth and the disk speed.

The results are then printed out in the logs, and also sent as part of telemetry, if telemetry is enabled.

overseer_channel_capacity_override: Option<usize>

Overseer message capacity override.

Dangerous! Do not touch unless explicitly adviced to.

workers_path: Option<PathBuf>

Path to the directory where auxiliary worker binaries reside.

If not specified, the main binary’s directory is searched first, then /usr/lib/polkadot is searched.

TESTING ONLY: if the path points to an executable rather then directory, that executable is used both as preparation and execution worker.

disable_worker_version_check: bool

TESTING ONLY: disable the version check between nodes and workers.