IdentifyVariant

Trait IdentifyVariant 

pub trait IdentifyVariant {
    // Required methods
    fn is_polkadot(&self) -> bool;
    fn is_kusama(&self) -> bool;
    fn is_westend(&self) -> bool;
    fn is_rococo(&self) -> bool;
    fn is_versi(&self) -> bool;
    fn is_dev(&self) -> bool;
    fn identify_chain(&self) -> Chain;
}
Can be called for a Configuration to identify which network the configuration targets.

Required Methods

fn is_polkadot(&self) -> bool

Returns if this is a configuration for the Polkadot network.

fn is_kusama(&self) -> bool

Returns if this is a configuration for the Kusama network.

fn is_westend(&self) -> bool

Returns if this is a configuration for the Westend network.

fn is_rococo(&self) -> bool

Returns if this is a configuration for the Rococo network.

fn is_versi(&self) -> bool

Returns if this is a configuration for the Versi test network.

fn is_dev(&self) -> bool

Returns true if this configuration is for a development network.

fn identify_chain(&self) -> Chain

Identifies the variant of the chain.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl IdentifyVariant for Box<dyn ChainSpec>

Implementors